@@ -45,10 +45,11 @@ Some key features
 """
     
 # Set version number
-__version__ = '3.5'
+__version__ = '3.7'
 
 import os
 import sys
+import locale
 
 # Check Python version
 if sys.version < '3':
@@ -85,7 +86,7 @@ from pyzolib import ssdf, paths
 from pyzolib.qt import QtCore, QtGui
 
 # Import language/translation tools
-from iep.util.locale import translate, setLanguage
+from iep.util._locale import translate, setLanguage
 
 # Set environ to let kernel know some stats about us
 os.environ['IEP_PREFIX'] = sys.prefix
@@ -225,6 +226,18 @@ def startIep():
     from iep.iepcore import iepLogging # to start logging asap
     from iep.iepcore.main import MainWindow
     
+    # Apply users' preferences w.r.t. date representation etc
+    # this is required for e.g. strftime("%c")
+    # Just using '' does not seem to work on OSX. Thus
+    # this odd loop.
+    #locale.setlocale(locale.LC_ALL, "")
+    for x in ('', 'C', 'en_US', 'en_US.utf8', 'en_US.UTF-8'):
+        try:
+            locale.setlocale(locale.LC_ALL, x)
+            break
+        except locale.Error:
+            pass
+    
     # Set to be aware of the systems native colors, fonts, etc.
     QtGui.QApplication.setDesktopSettingsAware(True)
     
@@ -232,10 +245,10 @@ def startIep():
     QtGui.qApp = MyApp([])  # QtGui.QApplication([])
     
     # Choose language, get locale
-    locale = setLanguage(config.settings.language)
+    appLocale = setLanguage(config.settings.language)
     
     # Create main window, using the selected locale
-    frame = MainWindow(None, locale)
+    frame = MainWindow(None, appLocale)
     
     # Enter the main loop
     QtGui.qApp.exec_()
