@@ -13,7 +13,9 @@ A full featured code editor component based on QPlainTextEdit.
 from .manager import Manager
 from .base import CodeEditorBase
 
-from .extensions.appearance import (    HighlightCurrentLine, 
+from .extensions.appearance import (    HighlightMatchingBracket,
+                                        HighlightMatchingOccurrences,
+                                        HighlightCurrentLine, 
                                         FullUnderlines,
                                         IndentationGuides,
                                         CodeFolding,
@@ -31,16 +33,19 @@ from .extensions.behaviour import (     Indentation,
                                         NumpadPeriodKey,
                                         AutoIndent,
                                         PythonAutoIndent,
+                                        SmartCopyAndPaste
                                    )
 from .extensions.autocompletion import AutoCompletion
 from .extensions.calltip import Calltip
 
  
 # Order of superclasses: first the extensions, then CodeEditorBase
-# The first superclass is the first extension that gets to handle each key
-# 
+# The first superclass is the first extension that gets to handle each key and
+# the first to receive paint events.
 class CodeEditor(
-    HighlightCurrentLine, 
+    HighlightCurrentLine,
+    HighlightMatchingOccurrences,
+    HighlightMatchingBracket,
     FullUnderlines,
     IndentationGuides, 
     CodeFolding,
@@ -64,7 +69,11 @@ class CodeEditor(
     
     SyntaxHighlighting,
     
-    CodeEditorBase):  #CodeEditorBase must be the last one in the list
+    SmartCopyAndPaste, # overrides cut(), copy(), paste()
+
+    CodeEditorBase, #CodeEditorBase must be the last one in the list
+    
+    ):  
     """
     CodeEditor with all the extensions
     """
