@@ -17,6 +17,231 @@ from ..manager import Manager
 # todo: what about calling all extensions. CE_HighlightCurrentLine, 
 # or EXT_HighlightcurrentLine?
 
+
+class HighlightMatchingOccurrences(object):
+    
+    # Register style element
+    _styleElements = [  (   'Editor.Highlight matching occurrences',
+                            'The background color to highlight matching occurrences of the currently selected word.',
+                            'back:#fdfda3', 
+                        ) ]
+
+
+    def highlightMatchingOccurrences(self):
+        """ highlightMatchingOccurrences()
+        
+        Get whether to highlight matching occurrences.
+        
+        """
+        return self.__highlightMatchingOccurrences
+    
+    
+    @ce_option(True)
+    def setHighlightMatchingOccurrences(self,value):
+        """ setHighlightMatchingOccurrences(value)
+        
+        Set whether to highlight matching occurrences.  
+        
+        """
+        self.__highlightMatchingOccurrences = bool(value)
+        self.viewport().update()
+
+
+    def _doHighlight(self, text):
+        # make cursor at the beginning of the first visible block
+        cursor = self.cursorForPosition(QtCore.QPoint(0,0))
+        doc = self.document()
+        
+        color = self.getStyleElementFormat('editor.highlightMatchingOccurrences').back
+        painter = QtGui.QPainter()
+        painter.begin(self.viewport())
+        painter.setBrush(color)
+        painter.setPen(color.darker(110))
+        
+        # find occurrences
+        while True:
+            cursor = doc.find(text, cursor,
+                doc.FindCaseSensitively | doc.FindWholeWords)
+            if cursor is None or cursor.isNull():
+                # no more matches
+                break
+                
+            # don't highlight the actual selection
+            if cursor == self.textCursor():
+                continue
+            
+            endRect = self.cursorRect(cursor)
+            if endRect.bottom() > self.height():
+                # rest of document is not visible, don't bother highlighting
+                break
+            
+            cursor.movePosition(cursor.Left, n=len(text))
+            startRect = self.cursorRect(cursor)
+            width = endRect.left() - startRect.left()
+            painter.drawRect(startRect.left(), startRect.top(), width, 
+                startRect.height())
+                
+            # move to end of word again, otherwise we never advance in the doc
+            cursor.movePosition(cursor.EndOfWord)
+            
+        painter.end()
+
+
+    def paintEvent(self, event):
+        """ paintEvent(event)
+        
+        If there is a current selection, and the selected text is a valid Python
+        identifier (no whitespace, starts with a letter), then highlight all the
+        matching occurrences of the selected text in the current view.
+        
+        Paints behinds its super().
+        
+        """
+        cursor = self.textCursor()
+        if self.__highlightMatchingOccurrences and cursor.hasSelection():
+            text = cursor.selectedText()
+            if text.isidentifier():
+                self._doHighlight(text)
+            
+        super(HighlightMatchingOccurrences, self).paintEvent(event)
+
+
+
+class HighlightMatchingBracket(object):
+    
+    # Register style element
+    _styleElements = [  (   'Editor.Highlight matching bracket',
+                            'The background color to highlight matching brackets.',
+                            'back:#ccc', 
+                        ) ]
+
+
+    def highlightMatchingBracket(self):
+        """ highlightMatchingBracket()
+        
+        Get whether to highlight matching brackets.
+        
+        """
+        return self.__highlightMatchingBracket
+    
+    
+    @ce_option(True)
+    def setHighlightMatchingBracket(self,value):
+        """ setHighlightMatchingBracket(value)
+        
+        Set whether to highlight matching brackets.  
+        
+        """
+        self.__highlightMatchingBracket = bool(value)
+        self.viewport().update()
+        
+    
+    def _highlightSingleChar(self, painter, cursor, width):
+            """ _highlightSingleChar(painter, cursor, width)
+            
+            Draws a highlighting rectangle around the single character to the
+            left of the specified cursor.
+            
+            """
+            cursor_rect = self.cursorRect(cursor)
+            top = cursor_rect.top()
+            left = cursor_rect.left() - width
+            height = cursor_rect.bottom() - top + 1
+            color = self.getStyleElementFormat('editor.highlightMatchingBracket').back
+            painter.setBrush(color)
+            painter.setPen(color.darker(110))
+            painter.drawRect(QtCore.QRect(left, top, width, height))
+
+
+    _matchingBrackets = {'(':')', '[':']', '{':'}', ')':'(', ']':'[', '}':'{'}
+    def _findMatchingBracket(self, char, cursor, doc):
+        """ _findMatchingBracket(char, cursor, doc)
+        
+        Find a bracket that matches the specified char in the specified document.
+        Bracket index is returned as a QtCursor instance, pointing to the right
+        of the found character. If no match is found, returns None.
+        
+        """
+        if char in ')]}':
+            direction = -1
+        elif char in '([{':
+            direction = 1
+        else:
+            raise ValueError('invalid bracket character: ' + char)
+            
+        other_char = self._matchingBrackets[char]
+        fulltext = doc.toPlainText()
+        pos = cursor.position() - 1
+        num_match = 0
+        while True:
+            if pos > len(fulltext)-1 or pos < 0:
+                return None
+            
+            if fulltext[pos] == char:
+                num_match += 1
+            elif fulltext[pos] == other_char:
+                num_match -= 1
+            
+            pos += direction
+            
+            if num_match == 0:
+                # we've found our match
+                # note that we want to return a cursor positioned *after* our
+                # match. In case of forward searching, that's where we are now.
+                # for backward searching, compensate by adding two.
+                new_cursor = QtGui.QTextCursor(doc)
+                if direction == -1:
+                    pos += 2
+                new_cursor.setPosition(pos)
+                return new_cursor
+
+    
+    def paintEvent(self, event):
+        """ paintEvent(event)
+        
+        If the current cursor is positioned to the right of a bracket ()[]{},
+        look for a matching one, and, if found, draw a highlighting rectangle
+        around both brackets of the pair.
+        
+        Paints behinds its super().
+        
+        """
+        if not self.__highlightMatchingBracket:
+            super(HighlightMatchingBracket, self).paintEvent(event)
+            return
+            
+        cursor = self.textCursor()
+        text = cursor.block().text()
+        pos = cursor.positionInBlock() - 1
+        
+        if not cursor.atBlockStart() and len(text) > pos and len(text) > 0:
+            # get the character to the left of the cursor
+            char = text[pos]
+            
+            if (char not in '()[]{}' and len(text) > pos+1
+                and text[pos+1] in '()[]{}'):
+                # no brace to the left of cursor; but one to the right
+                cursor = QtGui.QTextCursor(cursor)
+                cursor.movePosition(cursor.Right)
+                char = text[pos+1]
+                
+            doc = cursor.document()
+            if char in '()[]{}':
+                other_bracket = self._findMatchingBracket(char, cursor, doc)
+                if other_bracket is not None:
+                    fm = QtGui.QFontMetrics(doc.defaultFont())
+                    width = fm.width(char)
+                    
+                    painter = QtGui.QPainter()
+                    painter.begin(self.viewport())
+                    self._highlightSingleChar(painter, cursor, width)
+                    self._highlightSingleChar(painter, other_bracket, width)
+                    painter.end()
+            
+        super(HighlightMatchingBracket, self).paintEvent(event)
+
+ 
+
 class HighlightCurrentLine(object):
     """
     Highlight the current line
