@@ -5,9 +5,9 @@
 # The full license can be found in 'license.txt'.
 
 import re
-from . import tokens, Parser, BlockState
+from . import tokens, Parser, BlockState, text_type
 from .tokens import ALPHANUM
-
+from ..misc import ustr, bstr
 
 # Import tokens in module namespace
 from .tokens import (CommentToken, StringToken, 
@@ -119,6 +119,7 @@ class PythonParser(Parser):
         to handle line continuation and multiline strings.
         
         """ 
+        line = text_type(line)
         
         # Init
         pos = 0 # Position following the previous match
@@ -227,7 +228,7 @@ class PythonParser(Parser):
         # Return the Non-Identifier token if non-null
         # todo: here it goes wrong (allow returning more than one token?)
         token = NonIdentifierToken(line,pos,nonIdentifierEnd)
-        strippedNonIdentifier = str(token).strip()
+        strippedNonIdentifier = ustr(token).strip()
         if token:
             tokens.append(token)
         
