@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012, the IEP development team
+# Copyright (C) 2013, the IEP development team
 #
 # IEP is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
@@ -15,7 +15,7 @@ structure of a source file in for example a tree widget.
 #TODO: replace this module, get data from the syntax highlighter in the code editor
 
 import time, threading, re
-from iep.codeeditor.qt import QtCore, QtGui
+from pyzolib.qt import QtCore, QtGui
 import iep
 
 
@@ -81,6 +81,12 @@ class Parser(threading.Thread):
         
         # Set deamon
         self.daemon = True
+        self._exit = False
+    
+    
+    def stop(self, timeout=1.0):
+        self._exit = True
+        self.join(timeout)
     
     
     def parseThis(self, editor):
@@ -317,6 +323,10 @@ class Parser(threading.Thread):
         try:
             while True:
                 time.sleep(0.1)
+                
+                if self._exit:
+                    return
+                
                 if self._job:
                     
                     # Savely obtain job
@@ -396,7 +406,7 @@ class Parser(threading.Thread):
             linelen = len(line)
             
             # Should we stop?
-            if self._job:
+            if self._job or self._exit:
                 break
             
             # Remove indentation
@@ -664,7 +674,7 @@ def _findString(text, s, i):
     """ Helper function of findString, which is called recursively
     until a match is found, or it is clear there is no match. """
     
-    # Find occurance
+    # Find occurrence
     i2 = text.find(s, i)
     if i2<0:
         return -1
