@@ -486,18 +486,30 @@ class IepEditor(BaseTextCtrl):
         if self.testWhetherFileWasChanged():
             return
         
-        # Get text
+        # Get text and remember where we are
         text = self.toPlainText()
+        cursor = self.textCursor()
+        linenr = cursor.blockNumber() + 1
+        index = cursor.positionInBlock()
+        scroll = self.verticalScrollBar().value()
         
         # Convert line endings (optionally remove trailing whitespace
         if iep.config.settings.removeTrailingWhitespaceWhenSaving:
-            lines = []
-            for line in text.splitlines():
-                lines.append(line.rstrip())
+            lines = [line.rstrip() for line in text.split('\n')]
+            if lines[-1]:
+                lines.append('')  # Ensure the file ends in an empty line
             text = self.lineEndings.join(lines)
             self.setPlainText(text)
+            # Go back to where we were
+            cursor = self.textCursor()
+            cursor.movePosition(cursor.Start) # move to begin of the document
+            cursor.movePosition(cursor.NextBlock,n=linenr-1) # n blocks down
+            index = min(index, cursor.block().length()-1)
+            cursor.movePosition(cursor.Right,n=index) # n chars right
+            self.setTextCursor(cursor)
+            self.verticalScrollBar().setValue(scroll)
         else:
-            text.replace('\n', self.lineEndings)
+            text = text.replace('\n', self.lineEndings)
         
         # Make bytes
         bb = text.encode(self.encoding)
@@ -568,16 +580,28 @@ class IepEditor(BaseTextCtrl):
         cursor.movePosition(cursor.NextBlock, cursor.KeepAnchor)
         
         cursor.removeSelectedText()
-        
-        
+    
+    
     def commentCode(self):
         """
         Comment the lines that are currently selected
         """
-        self.doForSelectedBlocks(
-            lambda cursor: cursor.insertText('# ') )
-     
+        indents = []
+        
+        def getIndent(cursor):
+            text = cursor.block().text().rstrip()
+            if text:
+                indents.append(len(text) - len(text.lstrip()))
+        
+        def commentBlock(cursor):
+            cursor.setPosition(cursor.block().position() + minindent)
+            cursor.insertText('# ')
+        
+        self.doForSelectedBlocks(getIndent)
+        minindent = min(indents) if indents else 0 
+        self.doForSelectedBlocks(commentBlock)
     
+
     def uncommentCode(self):
         """
         Uncomment the lines that are currently selected
@@ -605,7 +629,7 @@ class IepEditor(BaseTextCtrl):
         #Apply this function to all blocks
         self.doForSelectedBlocks(uncommentBlock)
 
-    def gotoDef(self):
+   #   def gotoDef(self):
         """
         Goto the definition for the word under the cursor
         """
@@ -700,9 +724,23 @@ class IepEditor(BaseTextCtrl):
         
     
 if __name__=="__main__":
+    # Do some stubbing to run this module as a unit separate from iep
+    # TODO: untangle iep from this module where possible
+    class DummyParser:
+        def parseThis(self, x):
+            pass
+    iep.parser = DummyParser()    
+    EditorContextMenu = QtGui.QMenu
     app = QtGui.QApplication([])
     win = IepEditor(None)
-    win.setStyle('.py')
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+C"), win).activated.connect(win.copy)
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+X"), win).activated.connect(win.cut)
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+V"), win).activated.connect(win.paste)
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+Shift+V"), win).activated.connect(win.pasteAndSelect)
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+Z"), win).activated.connect(win.undo)
+    QtGui.QShortcut(QtGui.QKeySequence("Ctrl+Y"), win).activated.connect(win.redo)
+    
+    
     tmp = "foo(bar)\nfor bar in range(5):\n  print bar\n"
     tmp += "\nclass aap:\n  def monkey(self):\n    pass\n\n"
     win.setPlainText(tmp)    
