@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012, the IEP development team
+# Copyright (C) 2013, the IEP development team
 #
 # IEP is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
@@ -12,7 +12,7 @@ that show information to the user in a very effective, yet subtle manner.
 
 """
 
-from iep.codeeditor.qt import QtCore, QtGui
+from pyzolib.qt import QtCore, QtGui
 import iep
 
 
@@ -441,7 +441,7 @@ class TabToolButtonWithCloseButton(TabToolButton):
         if hasattr(self, '_cross1'):
             pm = self._cross1
         else:
-            pm = self._createCrossPixmap(80)
+            pm = self._createCrossPixmap(50)
         return pm
     
     def getCrossPixmap2(self):
@@ -711,4 +711,3 @@ class ShellIconMaker:
         # Done
         self.setIcon(artist.finish())
 
-    
\ No newline at end of file
