@@ -101,11 +101,6 @@ class MainWindow(QtGui.QMainWindow):
         self.paintNow()
         self.restoreState()
         
-        # Load basic tools if new user
-        if iep.config.state.newUser and not iep.config.state.loadedTools:
-            iep.toolManager.loadTool('iepsourcestructure')
-            iep.toolManager.loadTool('iepfilebrowser')
-        
         # Present user with wizard if he/she is new.
         if iep.config.state.newUser:
             from iep.util.iepwizard import IEPWizard
@@ -153,6 +148,10 @@ class MainWindow(QtGui.QMainWindow):
         # Instantiate tool manager
         iep.toolManager = ToolManager()
         
+        # Check to install conda now ...
+        from iep.util.bootstrapconda import check_for_conda_env
+        check_for_conda_env()
+        
         # Instantiate and start source-code parser
         if iep.parser is None:
             iep.parser = codeparser.Parser()
@@ -162,13 +161,12 @@ class MainWindow(QtGui.QMainWindow):
         iep.editors = EditorTabs(self)
         self.setCentralWidget(iep.editors)
         
-        
         # Create floater for shell
         self._shellDock = dock = QtGui.QDockWidget(self)
-        dock.setFeatures(dock.DockWidgetMovable)
+        dock.setFeatures(dock.DockWidgetMovable | dock.DockWidgetFloatable)
         dock.setObjectName('shells')
         dock.setWindowTitle('Shells')
-        self.addDockWidget(QtCore.Qt.TopDockWidgetArea, dock)
+        self.addDockWidget(QtCore.Qt.RightDockWidgetArea, dock)
         
         # Create shell stack
         iep.shells = ShellStackWidget(self)
@@ -177,7 +175,6 @@ class MainWindow(QtGui.QMainWindow):
         # Create the default shell when returning to the event queue
         callLater(iep.shells.addShell)
         
-        
         # Create statusbar
         if iep.config.view.showStatusbar:
             iep.status = self.statusBar()
@@ -195,11 +192,13 @@ class MainWindow(QtGui.QMainWindow):
         iep.shells.addContextMenu()
         
         # Load tools
-        if iep.config.state.loadedTools: 
+        if iep.config.state.newUser and not iep.config.state.loadedTools:
+            iep.toolManager.loadTool('iepsourcestructure')
+            iep.toolManager.loadTool('iepfilebrowser', 'iepsourcestructure')
+        elif iep.config.state.loadedTools: 
             for toolId in iep.config.state.loadedTools:
                 iep.toolManager.loadTool(toolId)
     
-    
     def setMainTitle(self, path=None):
         """ Set the title of the main window, by giving a file path.
         """
@@ -212,7 +211,7 @@ class MainWindow(QtGui.QMainWindow):
             if os.path.isfile(path):
                 pass
             elif name == path:
-                path = 'no location on disk'
+                path = 'unsaved'
             else:
                 pass  # We hope the given path is informative
             # Set title
