@@ -23,6 +23,7 @@ from pyzolib.qt import QtCore, QtGui
 import iep
 from iep.iepcore.compactTabWidget import CompactTabWidget
 from iep.iepcore.iepLogging import print
+from iep.iepcore.assistant import IepAssistant
 import webbrowser
 from iep import translate
 
@@ -618,6 +619,8 @@ class EditMenu(Menu):
             icons.page_white_copy, self._editItemCallback, "copy")
         self.addItem(translate("menu", "Paste ::: Paste the text that is now on the clipboard."), 
             icons.paste_plain, self._editItemCallback, "paste")
+        self.addItem(translate("menu", "Paste and select ::: Paste the text that is now on the clipboard and keep it selected in order to change its indentation."), 
+            icons.paste_plain, self._editItemCallback, "pasteAndSelect")
         self.addItem(translate("menu", "Select all ::: Select all text."), 
             icons.sum, self._editItemCallback, "selectAll")
         self.addSeparator()
@@ -755,6 +758,15 @@ class ViewMenu(Menu):
         self.addEditorItem(translate("menu", "Highlight current line ::: Highlight the line where the cursor is."), 
             None, "highlightCurrentLine")
         self.addSeparator()
+        self.addItem(translate("menu", "Previous cell ::: Go back to the previous cell."),
+            None, self._previousCell )
+        self.addItem(translate("menu", "Next cell ::: Advance to the next cell."),
+            None, self._nextCell )
+        self.addItem(translate("menu", "Previous object ::: Go back to the previous top-level structure."),
+            None, self._previousTopLevelObject )
+        self.addItem(translate("menu", "Next object ::: Advance to the next top-level structure."),
+            None, self._nextTopLevelObject )
+        self.addSeparator()
         self.addMenu(self._edgeColumMenu, icons.text_padding_right)
         self.addMenu(FontMenu(self, translate("menu", "Font")), icons.style)
         self.addMenu(ZoomMenu(self, translate("menu", "Zooming")), icons.magnifier)
@@ -802,6 +814,113 @@ class ViewMenu(Menu):
         iep.config.view.qtstyle = value
         iep.main.setQtStyle(value)
 
+    def _previousCell(self):
+        """
+        Rewind the curser to the previous cell (starting with '##').
+        """
+        self._previousTopLevelObject(type='cell')
+
+    def _nextCell(self):
+        """
+        Advance the curser to the next cell (starting with '##').
+        """
+        self._nextTopLevelObject(type='cell')
+
+    def _previousTopLevelObject(self, type=None):
+        # Get parser result
+        result = iep.parser._getResult()
+        if not result:
+            return
+        
+        # Get editor
+        editor = iep.editors.getCurrentEditor()
+        if not editor:
+            return
+        
+        # Get current line number
+        ln = editor.textCursor().blockNumber()
+        ln += 1  # is ln as in line number area
+        
+        runCursor = editor.textCursor() #The part that should be run
+        runCursor.movePosition(runCursor.StartOfBlock)
+        
+        # Find the object which starts above current curser
+        # position if there is any and move there
+        for object in reversed(result.rootItem.children):
+            # If type given, only consider objects of that type
+            if type and type!=object.type:
+                continue
+            if ln and object.linenr < ln:
+                startLineNr = object.linenr
+        
+                # Rewind cursor until the start of this object
+                while True:
+                    if not runCursor.block().previous().isValid():
+                        return
+                    runCursor.movePosition(runCursor.PreviousBlock)
+                    if runCursor.blockNumber() == startLineNr-1:
+                        break
+                
+                cursor = editor.textCursor()
+                cursor.setPosition(runCursor.position())
+                editor.setTextCursor(cursor)
+                return
+
+
+    def _nextTopLevelObject(self, type=None):
+        # Get parser result
+        result = iep.parser._getResult()
+        if not result:
+            return
+        
+        # Get editor
+        editor = iep.editors.getCurrentEditor()
+        if not editor:
+            return
+        
+        # Get current line number
+        ln = editor.textCursor().blockNumber()
+        ln += 1  # is ln as in line number area
+        
+        runCursor = editor.textCursor() #The part that should be run
+        runCursor.movePosition(runCursor.StartOfBlock)
+        
+        # Find the object which starts below current curser
+        # position if there is any and move there
+        for object in result.rootItem.children:
+            # If type given, only consider objects of that type
+            if type and type!=object.type:
+                continue
+            if ln and object.linenr > ln:
+                startLineNr = object.linenr
+                endLineNr = object.linenr2
+                
+                # Advance cursor until the start of this object
+                while True:
+                    if not runCursor.block().next().isValid():
+                        return
+                    runCursor.movePosition(runCursor.NextBlock)
+                    if runCursor.blockNumber() == startLineNr-1:
+                        break
+                
+                realCursorPosition = runCursor.position()
+                
+                # Advance cursor until the end of this object (to know
+                # how far it extends and make sure it is most visible)
+                while True:
+                    if not runCursor.block().next().isValid():
+                        break
+                    runCursor.movePosition(runCursor.NextBlock)
+                    if runCursor.blockNumber() == endLineNr-1:
+                        break
+                
+                cursor = editor.textCursor()
+                cursor.setPosition(runCursor.position())
+                editor.setTextCursor(cursor)
+                cursor.setPosition(realCursorPosition)
+                editor.setTextCursor(cursor)
+                return
+
 
 class ShellMenu(Menu):
     
@@ -884,6 +1003,8 @@ class ShellMenu(Menu):
         # Shell config
         self.addItem(translate("menu", 'Edit shell configurations... ::: Add new shell configs and edit interpreter properties.'), 
             iep.icons.application_wrench, self._editConfig2)
+        self.addItem(translate("menu", 'Create new Python environment... ::: Install miniconda.'), 
+            iep.icons.application_cascade, self._newPythonEnv)
         
         self.addSeparator()
         
@@ -938,6 +1059,11 @@ class ShellMenu(Menu):
         from iep.iepcore.shellInfoDialog import ShellInfoDialog 
         d = ShellInfoDialog()
         d.exec_()
+    
+    def _newPythonEnv(self):
+        from iep.util.bootstrapconda import Installer
+        d = Installer(iep.main)
+        d.exec_()
 
 
 class ShellButtonMenu(ShellMenu):
@@ -1191,6 +1317,7 @@ class RunMenu(Menu):
         shell = iep.shells.getCurrentShell()
         if shell is None:
             msg += "No shell to run code in. "
+            #shell = iep.shells.addShell()  # issue #335, does not work, somehow
         # Get editor
         if mainEditor:
             editor = iep.editors.getMainEditor()
@@ -1421,11 +1548,8 @@ class HelpMenu(Menu):
         if iep.pyzo_mode:
             issues_url = "http://pyzo.org/issues.html"
         
-        
-        if False:  # pyzo mode!  
-            # Work in progress
-            self.addItem(translate("menu", "Pyzo docs ::: Documentation on Python and the Scipy Stack."), 
-                icons.help, self._showPyzoDocs)
+        self.addItem(translate("menu", "Documentation ::: Documentation on Python and the Scipy Stack."), 
+            icons.help, self._showPyzoDocs)
         
         if iep.pyzo_mode:
             self.addUrlItem(translate("menu", "Pyzo Website ::: Open the Pyzo website in your browser."), 
@@ -1508,18 +1632,9 @@ class HelpMenu(Menu):
     
     
     def _showPyzoDocs(self):
-        # Get filename of doc collection
-        dirname = os.path.join(sys.prefix, 'share', 'pyzodocs')
-        #dirname = os.path.join('/home/almar/projects/pyzo_latest', 'share', 'pyzodocs')
-        fname = os.path.join(dirname, 'py.qhc')
-        
-        # Get exename of assistant
-        dirname = os.path.join(sys.prefix, 'bin', )
-        #dirname = os.path.join('/home/almar/projects/pyzo_latest', 'bin')
-        exename = os.path.join(dirname, 'assistant')
-        
-        import subprocess
-        iep._assistant = subprocess.Popen([exename , '-collectionFile', fname])
+        # Show widget with docs:
+        d = IepAssistant()
+        d.show()
 
 
 class SettingsMenu(Menu):
@@ -1527,7 +1642,7 @@ class SettingsMenu(Menu):
         icons = iep.icons
         
         # Create language menu
-        from iep.util.locale import LANGUAGES, LANGUAGE_SYNONYMS
+        from iep.util._locale import LANGUAGES, LANGUAGE_SYNONYMS
         # Update language setting if necessary
         cur = iep.config.settings.language
         iep.config.settings.language = LANGUAGE_SYNONYMS.get(cur, cur)
