@@ -71,6 +71,16 @@ class Browser(QtGui.QWidget):
             self._tree.SetPath(path)
         self._tree.dirChanged.emit(self._tree.path())
     
+    def getImportWizard(self):
+        # Lazy loading
+        try:
+            return self._importWizard
+        except AttributeError:
+            
+            from .importwizard import ImportWizard
+            self._importWizard = ImportWizard()
+            
+            return self._importWizard
     
     def _layout(self):
         layout = QtGui.QVBoxLayout(self)
@@ -411,9 +421,9 @@ class Projects(QtGui.QWidget):
         self._path = path
         # Find project index
         projectIndex, L = 0, 0
-        pathn = path.normcase()
+        pathn = path.normcase() + os.path.sep
         for i in range(self._combo.count()):
-            projectPath = self._combo.itemData(i)
+            projectPath = self._combo.itemData(i) + os.path.sep
             if pathn.startswith(projectPath) and len(projectPath) > L:
                 projectIndex, L = i, len(projectPath)
         # Select project or not ...
