@@ -80,13 +80,13 @@ class IepInteractiveHelp(QtGui.QWidget):
         # Put the elements together
         self._sizer2.addWidget(self._text, 4)
         self._sizer2.addWidget(self._printBut, 0)
-        self._sizer2.addStretch(1)
         self._sizer2.addWidget(self._options, 2)
         #
         self._sizer1.addLayout(self._sizer2, 0)
         self._sizer1.addWidget(self._browser, 1)
         #
         self._sizer1.setSpacing(2)
+        self._sizer1.setContentsMargins(4,4,4,4)
         self.setLayout(self._sizer1)
         
         # Set config
