@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012 Almar Klein
+# Copyright (C) 2013 Almar Klein
 #
 # Yoton is distributed under the terms of the (new) BSD License.
 # The full license can be found in 'license.txt'.
@@ -264,10 +264,20 @@ class TheTimerThread(threading.Thread):
     def __init__(self):
         threading.Thread.__init__(self)
         self.setDaemon(True)
+        self._exit = False
         self._timers = []
         self._somethingChanged = False
         self._condition = threading.Condition(threading.Lock())
     
+    def stop(self, timeout=1.0):
+        self._exit = True
+        self._condition.acquire()
+        try:
+            self._condition.notify()
+        finally:
+            self._condition.release()
+        self.join(timeout)
+    
     def add(self, timer):
         """ add(timer)
         Add item to the list of objects to track. The object should
@@ -311,7 +321,7 @@ class TheTimerThread(threading.Thread):
             self._condition.release()
     
     def _mainloop(self):
-        while True:
+        while not self._exit:
             
             # Set flag
             self._somethingChanged = False
@@ -327,6 +337,8 @@ class TheTimerThread(threading.Thread):
                 self._condition.wait()
             
             # Here the lock has been re-acquired. Take action?
+            if self._exit:
+                break
             if (timer is not None) and (not self._somethingChanged):
                 if timer._on_timeout():
                     self._sort()  # Keep and resort
